@@ -15,7 +15,7 @@ Usage::
 import sys
 from typing import Any, Dict, List, Type, overload
 
-from botocore.client import ClientMeta
+from botocore.client import BaseClient, ClientMeta
 
 from .literals import ClientVersionType
 from .paginator import ListHapgsPaginator, ListHsmsPaginator, ListLunaClientsPaginator
@@ -67,14 +67,19 @@ class Exceptions:
     InvalidRequestException: Type[BotocoreClientError]
 
 
-class CloudHSMClient:
+class CloudHSMClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html)
     """
 
     meta: ClientMeta
-    exceptions: Exceptions
+
+    @property
+    def exceptions(self) -> Exceptions:
+        """
+        CloudHSMClient exceptions.
+        """
 
     def add_tags_to_resource(
         self, *, ResourceArn: str, TagList: List["TagTypeDef"]
@@ -82,7 +87,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.add_tags_to_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#add_tags_to_resource)
         """
 
@@ -90,7 +95,7 @@ class CloudHSMClient:
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#can_paginate)
         """
 
@@ -98,7 +103,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.create_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hapg)
         """
 
@@ -117,7 +122,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.create_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_hsm)
         """
 
@@ -127,7 +132,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.create_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#create_luna_client)
         """
 
@@ -135,7 +140,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.delete_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hapg)
         """
 
@@ -143,7 +148,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.delete_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_hsm)
         """
 
@@ -151,7 +156,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.delete_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#delete_luna_client)
         """
 
@@ -159,7 +164,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.describe_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hapg)
         """
 
@@ -169,7 +174,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.describe_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_hsm)
         """
 
@@ -179,7 +184,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.describe_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#describe_luna_client)
         """
 
@@ -193,7 +198,7 @@ class CloudHSMClient:
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#generate_presigned_url)
         """
 
@@ -203,7 +208,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.get_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#get_config)
         """
 
@@ -211,7 +216,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.list_available_zones)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_available_zones)
         """
 
@@ -219,7 +224,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.list_hapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hapgs)
         """
 
@@ -227,7 +232,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.list_hsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_hsms)
         """
 
@@ -235,7 +240,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.list_luna_clients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_luna_clients)
         """
 
@@ -243,7 +248,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#list_tags_for_resource)
         """
 
@@ -253,7 +258,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.modify_hapg)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hapg)
         """
 
@@ -270,7 +275,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.modify_hsm)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_hsm)
         """
 
@@ -280,7 +285,7 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.modify_luna_client)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#modify_luna_client)
         """
 
@@ -290,21 +295,21 @@ class CloudHSMClient:
         """
         This is documentation for **AWS CloudHSM Classic**.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Client.remove_tags_from_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/client.html#remove_tags_from_resource)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hapgs"]) -> ListHapgsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHapgs)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhapgspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_hsms"]) -> ListHsmsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Paginator.ListHsms)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listhsmspaginator)
         """
 
@@ -313,6 +318,6 @@ class CloudHSMClient:
         self, operation_name: Literal["list_luna_clients"]
     ) -> ListLunaClientsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.0/reference/services/cloudhsm.html#CloudHSM.Paginator.ListLunaClients)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudhsm/paginators.html#listlunaclientspaginator)
         """
